"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.lazy = exports.createResource = undefined;

var _spy = require("./spy");

var _react = require("react");

var _react2 = _interopRequireDefault(_react);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var createResource = exports.createResource = function createResource(fetch, hashFunc) {
  return {
    preload: function preload(input) {
      return _spy.cachePublisher.preload({
        key: hashFunc ? hashFunc(input) : input,
        getValue: function getValue() {
          return fetch(input);
        }
      });
    },
    read: function read(input) {
      return _spy.cachePublisher.load({
        key: hashFunc ? hashFunc(input) : input,
        getValue: function getValue() {
          return fetch(input);
        }
      });
    }
  };
};

var extractImportName = function extractImportName(func) {
  var regex = /([A-z\.\-]*)(\.jsx?|\.tsx?)/;
  var result = func.toString().match(regex);
  if (result) {
    return result[1].trim();
  }
  return func.toString();
};

var lazy = exports.lazy = function lazy(fetch) {
  var resource = createResource(fetch, function () {
    return "lazy(" + extractImportName(fetch) + ")";
  });
  // const Component = React.lazy(fetch);
  // console.log(Component);
  return function (props) {
    var Component = resource.read().default;
    return _react2.default.createElement(Component, props);
  };
};
//# sourceMappingURL=new-cache.js.map